@@ -332,11 +332,16 @@ class dyagram:
             self.log.info(f"DEVICE: {device} - SSH : CREATED NETMIKO OBJ : discover_routes_ssh")
             dev.enable()
 
-            routes = dev.send_command("show ip route vrf all", use_textfsm=True)
-
-            for route in routes:
+            routes_w_vrf = dev.send_command("show ip route vrf all", use_textfsm=True)
+            routes_wo_vrf = dev.send_command("show ip route", use_textfsm=True)
+            for route in routes_w_vrf:
                 if 'uptime' in route.keys():
                     route.pop('uptime')
+            for route in routes_wo_vrf:
+                if 'uptime' in route.keys():
+                    route.pop('uptime')
+            combined_routes = routes_wo_vrf + routes_w_vrf
+            routes = [i for n, i in enumerate(combined_routes) if i not in combined_routes[n + 1:]]
 
             dev.disconnect()
             for i in self.topology['devices']:
